@@ -14,7 +14,7 @@ use base qw(Pod::Tree::PerlUtil);
 sub new
 {
     my %defaults = (col_width => 25,
-		    bgcolor   => '#fffff8',
+		    bgcolor   => '#ffffff',
 		    text      => '#000000');
     my($class, $perl_dir, $html_dir, $link_map, %options) = @_;
     my $options  = { %defaults, %options, link_map => $link_map };
@@ -312,5 +312,5 @@ Steven McDougall, swmcd@world.std.com
 
 =head1 COPYRIGHT
 
-Copyright 2000 by Steven McDougall.  This program is free software;
+Copyright (c) 2000 by Steven McDougall.  This module is free software;
 you can redistribute it and/or modify it under the same terms as Perl.
