@@ -11,7 +11,7 @@ use base qw(Pod::Tree::PerlUtil);
 
 sub new
 {
-    my %defaults = (bgcolor   => '#fffff8',
+    my %defaults = (bgcolor   => '#ffffff',
 		    text      => '#000000');
 
     my($class, $perl_dir, $html_dir, $link_map, %options) = @_;
@@ -334,5 +334,5 @@ Steven McDougall, swmcd@world.std.com
 
 =head1 COPYRIGHT
 
-Copyright 2000 by Steven McDougall.  This program is free software;
-you can redistribute it and/or modify it under the same terms as Perl.
+Copyright (c) 2000 by Steven McDougall.  This module is free software;
+you can redistribute it and/or modify it under the same terms as Perl itself.
